@@ -5,24 +5,32 @@ package Acme::Throw;
 # ABSTRACT: For when code makes you want to throw something.
 
 use utf8;
-use Carp qw/ croak /;
+
+our $MSG;
 
 sub import {
+  my ($class, %args) = @_;
 
+  $MSG = $args{-msg} || "WHY WON'T THIS CODE WORK??!?";
   my $orig_handler = $SIG{__DIE__};
 
   $SIG{__DIE__} = sub {
     binmode(STDERR, ":utf8");
-    print STDERR "(╯°□°）╯︵ ┻━┻ WHY WON'T THIS CODE WORK??!?\n";
+    print STDERR "(╯°□°）╯︵ ┻━┻  $MSG\n";
     $SIG{__DIE__} = $orig_handler;
     die @_;
   };
-
 }
 
+sub _msg { $MSG }
+
 1 && q{ THIS IS MY RAGE FACE }; # truth
 __END__
 
+=head1 NAME
+
+Acme::Throw - For when code makes you want to throw something.
+
 =head1 SYNOPSIS
 
   use Acme::Throw;
@@ -35,7 +43,7 @@ Alternatively,
 
 =head1 DESCRIPTION
 
-B<<<THIS CODE IS CRAP! IT'S SO BAD IT MAKES THE I<COMPUTER> ANGRY!!!>>>
+B<THIS CODE IS CRAP! IT'S SO BAD IT MAKES THE I<COMPUTER> ANGRY!!!>
 
 Do you feel that the error messages in your code don't express your
 frustration with enough I<oomph>? Do screens full of stack dumps fill
